==> grails-3.0.9-1-any.pkg.tar.xz: org/gradle/api/internal/initialization/RootClassLoaderScope.java <==
/*
 * Copyright 2013 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.api.internal.initialization;

import org.gradle.api.internal.initialization.loadercache.ClassLoaderCache;
import org.gradle.internal.classpath.ClassPath;
import org.gradle.internal.id.LongIdGenerator;

public class RootClassLoaderScope implements ClassLoaderScope {

    private final ClassLoader localClassLoader;
    private final ClassLoader exportClassLoader;
    private final ClassLoaderCache classLoaderCache;
    private final ScopeNodeIdentifier id;

    public RootClassLoaderScope(ClassLoader localClassLoader, ClassLoader exportClassLoader, ClassLoaderCache classLoaderCache) {
        this.localClassLoader = localClassLoader;
        this.exportClassLoader = exportClassLoader;
        this.classLoaderCache = classLoaderCache;
        this.id = new ScopeNodeIdentifier("root", new LongIdGenerator());
    }

    public ClassLoader getLocalClassLoader() {
        return localClassLoader;
    }

    public ClassLoader getExportClassLoader() {
        return exportClassLoader;
    }

    public ClassLoaderScope getParent() {
        return this; // should this be null?
    }

    @Override
    public boolean defines(Class<?> clazz) {
        return localClassLoader.equals(clazz.getClassLoader()) || exportClassLoader.equals(clazz.getClassLoader());
    }

    public ClassLoaderScope local(ClassPath classPath) {
        throw new UnsupportedOperationException("root class loader scope is immutable");
    }

    public ClassLoaderScope export(ClassPath classPath) {
        throw new UnsupportedOperationException("root class loader scope is immutable");
    }

    public ClassLoaderScope createChild() {
        return new DefaultClassLoaderScope(id.newChild(), this, classLoaderCache);
    }

    public ClassLoaderScope lock() {
        return this;
    }

    public boolean isLocked() {
        return true;
    }
}

==> grails-3.1.4-1-any.pkg.tar.xz: org/gradle/api/internal/initialization/RootClassLoaderScope.java <==
/*
 * Copyright 2013 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.api.internal.initialization;

import org.gradle.api.internal.initialization.loadercache.ClassLoaderCache;
import org.gradle.internal.classpath.ClassPath;

public class RootClassLoaderScope implements ClassLoaderScope {

    private final ClassLoader localClassLoader;
    private final ClassLoader exportClassLoader;
    private final ClassLoaderCache classLoaderCache;
    private final ClassLoaderScopeIdentifier id;

    public RootClassLoaderScope(ClassLoader localClassLoader, ClassLoader exportClassLoader, ClassLoaderCache classLoaderCache) {
        this.localClassLoader = localClassLoader;
        this.exportClassLoader = exportClassLoader;
        this.classLoaderCache = classLoaderCache;
        this.id = new ClassLoaderScopeIdentifier(null, "root");
    }

    public ClassLoader getLocalClassLoader() {
        return localClassLoader;
    }

    public ClassLoader getExportClassLoader() {
        return exportClassLoader;
    }

    public ClassLoaderScope getParent() {
        return this; // should this be null?
    }

    @Override
    public boolean defines(Class<?> clazz) {
        return localClassLoader.equals(clazz.getClassLoader()) || exportClassLoader.equals(clazz.getClassLoader());
    }

    public ClassLoaderScope local(ClassPath classPath) {
        throw new UnsupportedOperationException("root class loader scope is immutable");
    }

    public ClassLoaderScope export(ClassPath classPath) {
        throw new UnsupportedOperationException("root class loader scope is immutable");
    }

    public ClassLoaderScope createChild(String name) {
        if (name == null) {
            throw new IllegalArgumentException("'name' cannot be null");
        }
        return new DefaultClassLoaderScope(id.child(name), this, classLoaderCache);
    }

    public ClassLoaderScope lock() {
        return this;
    }

    public boolean isLocked() {
        return true;
    }
}
